==> yatex-1.72-noarch-P2.tgz: usr/share/doc/yatex-1.72/files/patch-yatex.el <==
*** yatex1.72/yatex.el.orig	2006-09-18 14:18:33.000000000 +0900
--- yatex1.72/yatex.el	2006-09-18 14:19:41.000000000 +0900
***************
*** 67,73 ****
  
  (defvar dviprint-command-format
    (if YaTeX-dos "dviprt %s %f%t"
!       "dvi2ps %f %t %s | lpr")
    "*Command line string to print out current file.
  Format string %s will be replaced by the filename.  Do not forget to
  specify the `from usage' and `to usage' with their option by format string
--- 67,73 ----
  
  (defvar dviprint-command-format
    (if YaTeX-dos "dviprt %s %f%t"
!       "dvips %f %t %s.dvi -o - | lpr")
    "*Command line string to print out current file.
  Format string %s will be replaced by the filename.  Do not forget to
  specify the `from usage' and `to usage' with their option by format string
***************
*** 75,85 ****
    See also documentation of dviprint-from-format and dviprint-to-format.")
  
  (defvar dviprint-from-format
!   (if YaTeX-dos "%b-" "-f %b")
    "*`From' page format of dvi filter.  %b will turn to beginning page number.")
  
  (defvar dviprint-to-format
!   (if YaTeX-dos "%e" "-t %e")
    "*`To' page format of dvi filter.  %e will turn to end page number.")
  
  (defvar YaTeX-default-document-style
--- 75,85 ----
    See also documentation of dviprint-from-format and dviprint-to-format.")
  
  (defvar dviprint-from-format
!   (if YaTeX-dos "%b-" "-p %b")
    "*`From' page format of dvi filter.  %b will turn to beginning page number.")
  
  (defvar dviprint-to-format
!   (if YaTeX-dos "%e" "-l %e")
    "*`To' page format of dvi filter.  %e will turn to end page number.")
  
  (defvar YaTeX-default-document-style

==> yatex-1.73-noarch-P2.tgz: usr/share/doc/yatex-1.73/files/patch-yatex.el <==
*** yatex1.73/yatex.el.orig	2006-09-18 14:18:33.000000000 +0900
--- yatex1.73/yatex.el	2006-09-18 14:19:41.000000000 +0900
***************
*** 67,73 ****
  
  (defvar dviprint-command-format
    (if YaTeX-dos "dviprt %s %f%t"
!       "dvi2ps %f %t %s | lpr")
    "*Command line string to print out current file.
  Format string %s will be replaced by the filename.  Do not forget to
  specify the `from usage' and `to usage' with their option by format string
--- 67,73 ----
  
  (defvar dviprint-command-format
    (if YaTeX-dos "dviprt %s %f%t"
!       "dvips %f %t %s -o - | lpr")
    "*Command line string to print out current file.
  Format string %s will be replaced by the filename.  Do not forget to
  specify the `from usage' and `to usage' with their option by format string
***************
*** 75,85 ****
    See also documentation of dviprint-from-format and dviprint-to-format.")
  
  (defvar dviprint-from-format
!   (if YaTeX-dos "%b-" "-f %b")
    "*`From' page format of dvi filter.  %b will turn to beginning page number.")
  
  (defvar dviprint-to-format
!   (if YaTeX-dos "%e" "-t %e")
    "*`To' page format of dvi filter.  %e will turn to end page number.")
  
  (defvar YaTeX-default-document-style
--- 75,85 ----
    See also documentation of dviprint-from-format and dviprint-to-format.")
  
  (defvar dviprint-from-format
!   (if YaTeX-dos "%b-" "-p %b")
    "*`From' page format of dvi filter.  %b will turn to beginning page number.")
  
  (defvar dviprint-to-format
!   (if YaTeX-dos "%e" "-l %e")
    "*`To' page format of dvi filter.  %e will turn to end page number.")
  
  (defvar YaTeX-default-document-style
